diff --git a/components/lib/message/style/MessageStyle.js b/components/lib/message/style/MessageStyle.js
index e8c90e0d7a..b59544aebb 100644
--- a/components/lib/message/style/MessageStyle.js
+++ b/components/lib/message/style/MessageStyle.js
@@ -2,7 +2,7 @@ import BaseStyle from 'primevue/base/style';
const classes = {
root: ({ props }) => 'p-message p-component p-message-' + props.severity,
- wrapper: 'p-message-content',
+ content: 'p-message-content',
icon: 'p-message-icon',
text: 'p-message-text',
closeButton: 'p-message-close-button',
diff --git a/components/lib/metergroup/MeterGroup.vue b/components/lib/metergroup/MeterGroup.vue
index c04e41ac36..5f3f43f7a3 100644
--- a/components/lib/metergroup/MeterGroup.vue
+++ b/components/lib/metergroup/MeterGroup.vue
@@ -4,7 +4,7 @@
-
diff --git a/components/lib/metergroup/MeterGroup.d.ts b/components/lib/metergroup/MeterGroup.d.ts
index 08ed74d160..fd6b84f2ce 100644
--- a/components/lib/metergroup/MeterGroup.d.ts
+++ b/components/lib/metergroup/MeterGroup.d.ts
@@ -54,29 +54,33 @@ export interface MeterGroupPassThroughOptions {
*/
root?: MeterGroupPassThroughOptionType;
/**
- * Used to pass attributes to the label list's DOM element.
+ * Used to pass attributes to the meter container's DOM element.
*/
- labellist?: MeterGroupPassThroughOptionType;
+ meters?: MeterGroupPassThroughOptionType;
/**
- * Used to pass attributes to the label list item's DOM element.
+ * Used to pass attributes to the meter's DOM element.
*/
- labellistitem?: MeterGroupPassThroughOptionType;
+ meter?: MeterGroupPassThroughOptionType;
/**
- * Used to pass attributes to the label list type's DOM element.
+ * Used to pass attributes to the label list's DOM element.
*/
- labellisttype?: MeterGroupPassThroughOptionType;
+ labelList?: MeterGroupPassThroughOptionType;
/**
* Used to pass attributes to the label's DOM element.
*/
label?: MeterGroupPassThroughOptionType;
/**
* Used to pass attributes to the meter container's DOM element.
*/
- metercontainer?: MeterGroupPassThroughOptionType;
+ labelIcon?: MeterGroupPassThroughOptionType;
/**
* Used to pass attributes to the meter's DOM element.
*/
- meter?: MeterGroupPassThroughOptionType;
+ labelMarker?: MeterGroupPassThroughOptionType;
+ /**
+ * Used to pass attributes to the label's DOM element.
+ */
+ labelText?: MeterGroupPassThroughOptionType;
}
/**
@@ -54,29 +54,33 @@ export interface MeterGroupPassThroughOptions {
/**
- * Used to pass attributes to the label's DOM element.
+ * Used to pass attributes to the label list item's DOM element.
*/
label?: MeterGroupPassThroughOptionType;
@@ -54,29 +54,33 @@ export interface MeterGroupPassThroughOptions {
label?: MeterGroupPassThroughOptionType;
/**
- * Used to pass attributes to the meter container's DOM element.
+ * Used to pass attributes to the label icon type's DOM element.
*/
@@ -54,29 +54,33 @@ export interface MeterGroupPassThroughOptions {
/**
- * Used to pass attributes to the meter's DOM element.
+ * Used to pass attributes to the label list type's DOM element.
*/